| make_DEgene_dotplot_pseudobulk_reversed | R Documentation |
make_DEgene_dotplot_pseudobulk_reversed Visualize the scaled pseudobulk expression of DE genes per sample, and compare the different groups. Genes and sample positions are reversed compared to 'make_DEgene_dotplot_pseudobulk': genes in columns, samples in rows.
make_DEgene_dotplot_pseudobulk_reversed(genes_oi, celltype_info, abundance_data, celltype_oi, groups_oi = NA)
genes_oi |
Character vector with names of genes to visualize |
celltype_info |
'celltype_info' slot of the output of the 'muscat_analysis()' function |
abundance_data |
'abundance_data' slot of the output of the 'get_abundance_info()' function |
celltype_oi |
Character vector with names of celltype of interest |
groups_oi |
Which groups to show? Default: NULL – will show all groups. |
Gene expression dotplot list: pseudobulk version and single-cell version
## Not run:
library(dplyr)
sample_id = "tumor"
group_id = "pEMT"
celltype_id = "celltype"
covariates = NA
contrasts_oi = c("'High-Low','Low-High'")
contrast_tbl = tibble(contrast = c("High-Low","Low-High"), group = c("High","Low"))
min_cells = 10
abundance_output = get_abundance_info(sce, sample_id, group_id, celltype_id, min_cells, covariates = NA)
muscat_output = muscat_analysis(
sce = sce,
celltype_id = celltype_id,
sample_id = sample_id,
group_id = group_id,
covariates = covariates,
contrasts_oi = contrasts_oi,
contrast_tbl = contrast_tbl)
celltype_oi = "Malignant"
DE_table = filter(muscat_output$celltype_de$celltype_de$de_output_tidy,
cluster_id == celltype_oi &
p_adj <= 0.05 & logFC >= 1)
DE_genes = unique(DE_table$gene)
dotplots = make_DEgene_dotplot_pseudobulk_reversed(genes_oi = DE_genes, celltype_info = muscat_output$celltype_info, abundance_data = abundance_output$abundance_data, celltype_oi = celltype_oi)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.